# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/logicmodule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import logicmodule_messages_pb2 as protos_dot_logicmodule__messages__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18protos/logicmodule.proto\x12\x12protos.logicmodule\x1a!protos/logicmodule_messages.proto\x1a\x1cprotos/common_messages.proto2\xb5[\n\x0bLogicModule\x12[\n\x0e\x61utoregisterSL\x12).protos.logicmodule.AutoRegisterSLRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12i\n\x0e\x61utoregisterEE\x12).protos.logicmodule.AutoRegisterEERequest\x1a*.protos.logicmodule.AutoRegisterEEResponse\"\x00\x12q\n\x19unregisterStorageLocation\x12\x34.protos.logicmodule.UnregisterStorageLocationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12{\n\x1eunregisterExecutionEnvironment\x12\x39.protos.logicmodule.UnregisterExecutionEnvironmentRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12I\n\ncheckAlive\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x83\x01\n\"notifyExecutionEnvironmentShutdown\x12=.protos.logicmodule.NotifyExecutionEnvironmentShutdownRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12y\n\x1dnotifyStorageLocationShutdown\x12\x38.protos.logicmodule.NotifyStorageLocationShutdownRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x96\x01\n\x1d\x65xistsActiveEnvironmentsForSL\x12\x38.protos.logicmodule.ExistsActiveEnvironmentsForSLRequest\x1a\x39.protos.logicmodule.ExistsActiveEnvironmentsForSLResponse\"\x00\x12z\n\x17performSetOfNewAccounts\x12-.protos.logicmodule.PerformSetAccountsRequest\x1a..protos.logicmodule.PerformSetAccountsResponse\"\x00\x12}\n\x16performSetOfOperations\x12/.protos.logicmodule.PerformSetOperationsRequest\x1a\x30.protos.logicmodule.PerformSetOperationsResponse\"\x00\x12[\n\x0epublishAddress\x12).protos.logicmodule.PublishAddressRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12k\n\x11newAccountNoAdmin\x12,.protos.logicmodule.NewAccountNoAdminRequest\x1a&.protos.logicmodule.NewAccountResponse\"\x00\x12]\n\nnewAccount\x12%.protos.logicmodule.NewAccountRequest\x1a&.protos.logicmodule.NewAccountResponse\"\x00\x12\x63\n\x0cgetAccountID\x12\'.protos.logicmodule.GetAccountIDRequest\x1a(.protos.logicmodule.GetAccountIDResponse\"\x00\x12i\n\x0egetAccountList\x12).protos.logicmodule.GetAccountListRequest\x1a*.protos.logicmodule.GetAccountListResponse\"\x00\x12]\n\nnewSession\x12%.protos.logicmodule.NewSessionRequest\x1a&.protos.logicmodule.NewSessionResponse\"\x00\x12~\n\x15getInfoOfSessionForDS\x12\x30.protos.logicmodule.GetInfoOfSessionForDSRequest\x1a\x31.protos.logicmodule.GetInfoOfSessionForDSResponse\"\x00\x12\x63\n\x0cnewNamespace\x12\'.protos.logicmodule.NewNamespaceRequest\x1a(.protos.logicmodule.NewNamespaceResponse\"\x00\x12]\n\x0fremoveNamespace\x12*.protos.logicmodule.RemoveNamespaceRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12i\n\x0egetNamespaceID\x12).protos.logicmodule.GetNamespaceIDRequest\x1a*.protos.logicmodule.GetNamespaceIDResponse\"\x00\x12o\n\x10getNamespaceLang\x12+.protos.logicmodule.GetNamespaceLangRequest\x1a,.protos.logicmodule.GetNamespaceLangResponse\"\x00\x12u\n\x12getObjectDataSetID\x12-.protos.logicmodule.GetObjectDataSetIDRequest\x1a..protos.logicmodule.GetObjectDataSetIDResponse\"\x00\x12]\n\x0fimportInterface\x12*.protos.logicmodule.ImportInterfaceRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12[\n\x0eimportContract\x12).protos.logicmodule.ImportContractRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x90\x01\n\x1bgetInfoOfClassesInNamespace\x12\x36.protos.logicmodule.GetInfoOfClassesInNamespaceRequest\x1a\x37.protos.logicmodule.GetInfoOfClassesInNamespaceResponse\"\x00\x12\xa2\x01\n!getImportedClassesInfoInNamespace\x12<.protos.logicmodule.GetImportedClassesInfoInNamespaceRequest\x1a=.protos.logicmodule.GetImportedClassesInfoInNamespaceResponse\"\x00\x12{\n\x14getClassIDfromImport\x12/.protos.logicmodule.GetClassIDFromImportRequest\x1a\x30.protos.logicmodule.GetClassIDFromImportResponse\"\x00\x12\x66\n\rgetNamespaces\x12(.protos.logicmodule.GetNamespacesRequest\x1a).protos.logicmodule.GetNamespacesResponse\"\x00\x12]\n\nnewDataSet\x12%.protos.logicmodule.NewDataSetRequest\x1a&.protos.logicmodule.NewDataSetResponse\"\x00\x12Y\n\rremoveDataSet\x12(.protos.logicmodule.RemoveDataSetRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x63\n\x0cgetDataSetID\x12\'.protos.logicmodule.GetDataSetIDRequest\x1a(.protos.logicmodule.GetDataSetIDResponse\"\x00\x12{\n\x14\x63heckDataSetIsPublic\x12/.protos.logicmodule.CheckDataSetIsPublicRequest\x1a\x30.protos.logicmodule.CheckDataSetIsPublicResponse\"\x00\x12r\n\x11getPublicDataSets\x12,.protos.logicmodule.GetPublicDataSetsRequest\x1a-.protos.logicmodule.GetPublicDataSetsResponse\"\x00\x12u\n\x12getAccountDataSets\x12-.protos.logicmodule.GetAccountDataSetsRequest\x1a..protos.logicmodule.GetAccountDataSetsResponse\"\x00\x12W\n\x08newClass\x12#.protos.logicmodule.NewClassRequest\x1a$.protos.logicmodule.NewClassResponse\"\x00\x12U\n\x0bremoveClass\x12&.protos.logicmodule.RemoveClassRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\x0fremoveOperation\x12*.protos.logicmodule.RemoveOperationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12g\n\x14removeImplementation\x12/.protos.logicmodule.RemoveImplementationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12i\n\x0egetOperationID\x12).protos.logicmodule.GetOperationIDRequest\x1a*.protos.logicmodule.GetOperationIDResponse\"\x00\x12\x66\n\rgetPropertyID\x12(.protos.logicmodule.GetPropertyIDRequest\x1a).protos.logicmodule.GetPropertyIDResponse\"\x00\x12]\n\ngetClassID\x12%.protos.logicmodule.GetClassIDRequest\x1a&.protos.logicmodule.GetClassIDResponse\"\x00\x12\x63\n\x0cgetClassInfo\x12\'.protos.logicmodule.GetClassInfoRequest\x1a(.protos.logicmodule.GetClassInfoResponse\"\x00\x12`\n\x0bnewContract\x12&.protos.logicmodule.NewContractRequest\x1a\'.protos.logicmodule.NewContractResponse\"\x00\x12o\n\x18registerToPublicContract\x12\x33.protos.logicmodule.RegisterToPublicContractRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\xa8\x01\n#registerToPublicContractOfNamespace\x12>.protos.logicmodule.RegisterToPublicContractOfNamespaceRequest\x1a?.protos.logicmodule.RegisterToPublicContractOfNamespaceResponse\"\x00\x12\x8a\x01\n\x19getContractIDsOfApplicant\x12\x34.protos.logicmodule.GetContractIDsOfApplicantRequest\x1a\x35.protos.logicmodule.GetContractIDsOfApplicantResponse\"\x00\x12\x87\x01\n\x18getContractIDsOfProvider\x12\x33.protos.logicmodule.GetContractIDsOfProviderRequest\x1a\x34.protos.logicmodule.GetContractIDsOfProviderResponse\"\x00\x12\xa2\x01\n%getContractIDsOfApplicantWithProvider\x12:.protos.logicmodule.GetContractsOfApplicantWithProvRequest\x1a;.protos.logicmodule.GetContractsOfApplicantWithProvResponse\"\x00\x12l\n\x0fnewDataContract\x12*.protos.logicmodule.NewDataContractRequest\x1a+.protos.logicmodule.NewDataContractResponse\"\x00\x12w\n\x1cregisterToPublicDataContract\x12\x37.protos.logicmodule.RegisterToPublicDataContractRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x96\x01\n\x1dgetDataContractIDsOfApplicant\x12\x38.protos.logicmodule.GetDataContractIDsOfApplicantRequest\x1a\x39.protos.logicmodule.GetDataContractIDsOfApplicantResponse\"\x00\x12\x93\x01\n\x1cgetDataContractIDsOfProvider\x12\x37.protos.logicmodule.GetDataContractIDsOfProviderRequest\x1a\x38.protos.logicmodule.GetDataContractIDsOfProviderResponse\"\x00\x12\xb5\x01\n*getDataContractInfoOfApplicantWithProvider\x12\x41.protos.logicmodule.GetDataContractInfoOfApplicantWithProvRequest\x1a\x42.protos.logicmodule.GetDataContractInfoOfApplicantWithProvResponse\"\x00\x12\x63\n\x0cnewInterface\x12\'.protos.logicmodule.NewInterfaceRequest\x1a(.protos.logicmodule.NewInterfaceResponse\"\x00\x12o\n\x10getInterfaceInfo\x12+.protos.logicmodule.GetInterfaceInfoRequest\x1a,.protos.logicmodule.GetInterfaceInfoResponse\"\x00\x12]\n\x0fremoveInterface\x12*.protos.logicmodule.RemoveInterfaceRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x9c\x01\n\x1fgetAllExecutionEnvironmentsInfo\x12:.protos.logicmodule.GetAllExecutionEnvironmentsInfoRequest\x1a;.protos.logicmodule.GetAllExecutionEnvironmentsInfoResponse\"\x00\x12{\n\x14getStorageLocationID\x12/.protos.logicmodule.GetStorageLocationIDRequest\x1a\x30.protos.logicmodule.GetStorageLocationIDResponse\"\x00\x12\x81\x01\n\x16getStorageLocationInfo\x12\x31.protos.logicmodule.GetStorageLocationInfoRequest\x1a\x32.protos.logicmodule.GetStorageLocationInfoResponse\"\x00\x12\x90\x01\n\x1bgetExecutionEnvironmentInfo\x12\x36.protos.logicmodule.GetExecutionEnvironmentInfoRequest\x1a\x37.protos.logicmodule.GetExecutionEnvironmentInfoResponse\"\x00\x12\x66\n\rgetObjectInfo\x12(.protos.logicmodule.GetObjectInfoRequest\x1a).protos.logicmodule.GetObjectInfoResponse\"\x00\x12u\n\x12getObjectFromAlias\x12-.protos.logicmodule.GetObjectFromAliasRequest\x1a..protos.logicmodule.GetObjectFromAliasResponse\"\x00\x12`\n\x0b\x64\x65leteAlias\x12&.protos.logicmodule.DeleteAliasRequest\x1a\'.protos.logicmodule.DeleteAliasResponse\"\x00\x12\xa5\x01\n\"getObjectsMetaDataInfoOfClassForNM\x12=.protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMRequest\x1a>.protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMResponse\"\x00\x12O\n\x08\x61\x64\x64\x41lias\x12#.protos.logicmodule.AddAliasRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x66\n\x14registerObjectFromGC\x12..protos.logicmodule.RegisterObjectForGCRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x61\n\x11unregisterObjects\x12,.protos.logicmodule.UnregisterObjectsRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12l\n\x0fregisterObjects\x12*.protos.logicmodule.RegisterObjectsRequest\x1a+.protos.logicmodule.RegisterObjectsResponse\"\x00\x12\x7f\n setDataSetIDFromGarbageCollector\x12;.protos.logicmodule.SetDataSetIDFromGarbageCollectorRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12o\n\x10getMetadataByOID\x12+.protos.logicmodule.GetMetadataByOIDRequest\x1a,.protos.logicmodule.GetMetadataByOIDResponse\"\x00\x12T\n\rgetNumObjects\x12\x1b.protos.common.EmptyMessage\x1a$.protos.common.GetNumObjectsResponse\"\x00\x12W\n\x0csetDataSetID\x12\'.protos.logicmodule.SetDataSetIDRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\nmoveObject\x12%.protos.logicmodule.MoveObjectRequest\x1a&.protos.logicmodule.MoveObjectResponse\"\x00\x12\x61\n\x11setObjectReadOnly\x12,.protos.logicmodule.SetObjectReadOnlyRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x63\n\x12setObjectReadWrite\x12-.protos.logicmodule.SetObjectReadWriteRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12~\n\x15\x65xecuteImplementation\x12\x30.protos.logicmodule.ExecuteImplementationRequest\x1a\x31.protos.logicmodule.ExecuteImplementationResponse\"\x00\x12~\n\x15\x65xecuteMethodOnTarget\x12\x30.protos.logicmodule.ExecuteMethodOnTargetRequest\x1a\x31.protos.logicmodule.ExecuteMethodOnTargetResponse\"\x00\x12Y\n\rgetDataClayID\x12\x1b.protos.common.EmptyMessage\x1a).protos.logicmodule.GetDataClayIDResponse\"\x00\x12\x87\x01\n\x18registerExternalDataClay\x12\x33.protos.logicmodule.RegisterExternalDataClayRequest\x1a\x34.protos.logicmodule.RegisterExternalDataClayResponse\"\x00\x12\xa9\x01\n)registerExternalDataClayOverrideAuthority\x12\x44.protos.logicmodule.RegisterExternalDataClayOverrideAuthorityRequest\x1a\x34.protos.logicmodule.RegisterExternalDataClayResponse\"\x00\x12\xab\x01\n$notifyRegistrationOfExternalDataClay\x12?.protos.logicmodule.NotifyRegistrationOfExternalDataClayRequest\x1a@.protos.logicmodule.NotifyRegistrationOfExternalDataClayResponse\"\x00\x12z\n\x17getExternalDataClayInfo\x12-.protos.logicmodule.GetExtDataClayInfoRequest\x1a..protos.logicmodule.GetExtDataClayInfoResponse\"\x00\x12~\n\x15getExternalDataclayId\x12\x30.protos.logicmodule.GetExternalDataclayIDRequest\x1a\x31.protos.logicmodule.GetExternalDataclayIDResponse\"\x00\x12~\n\x15getClassesInNamespace\x12\x30.protos.logicmodule.GetClassesInNamespaceRequest\x1a\x31.protos.logicmodule.GetClassesInNamespaceResponse\"\x00\x12\x7f\n importModelsFromExternalDataClay\x12;.protos.logicmodule.ImportModelsFromExternalDataClayRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12W\n\x08getStubs\x12#.protos.logicmodule.GetStubsRequest\x1a$.protos.logicmodule.GetStubsResponse\"\x00\x12\x66\n\rgetBabelStubs\x12(.protos.logicmodule.GetBabelStubsRequest\x1a).protos.logicmodule.GetBabelStubsResponse\"\x00\x12U\n\x0bregisterECA\x12&.protos.logicmodule.RegisterECARequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12U\n\x0b\x61\x64viseEvent\x12&.protos.logicmodule.AdviseEventRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12g\n\x14isPrefetchingEnabled\x12\x1b.protos.common.EmptyMessage\x1a\x30.protos.logicmodule.IsPrefetchingEnabledResponse\"\x00\x12r\n\x11getClassNameForDS\x12,.protos.logicmodule.GetClassNameForDSRequest\x1a-.protos.logicmodule.GetClassNameForDSResponse\"\x00\x12\x96\x01\n\x1dgetClassNameAndNamespaceForDS\x12\x38.protos.logicmodule.GetClassNameAndNamespaceForDSRequest\x1a\x39.protos.logicmodule.GetClassNameAndNamespaceForDSResponse\"\x00\x12\x9c\x01\n\x1fgetContractIDOfDataClayProvider\x12:.protos.logicmodule.GetContractIDOfDataClayProviderRequest\x1a;.protos.logicmodule.GetContractIDOfDataClayProviderResponse\"\x00\x12\x81\x01\n\x16objectExistsInDataClay\x12\x31.protos.logicmodule.ObjectExistsInDataClayRequest\x1a\x32.protos.logicmodule.ObjectExistsInDataClayResponse\"\x00\x12W\n\x0c\x63loseSession\x12\'.protos.logicmodule.CloseSessionRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12~\n\x15getMetadataByOIDForDS\x12\x30.protos.logicmodule.GetMetadataByOIDForDSRequest\x1a\x31.protos.logicmodule.GetMetadataByOIDForDSResponse\"\x00\x12]\n\x0f\x61\x63tivateTracing\x12*.protos.logicmodule.ActivateTracingRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12P\n\x11\x64\x65\x61\x63tivateTracing\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12L\n\tgetTraces\x12\x1b.protos.common.EmptyMessage\x1a .protos.common.GetTracesResponse\"\x00\x12R\n\x13\x63leanMetaDataCaches\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12M\n\x0e\x63loseManagerDb\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x46\n\x07\x63loseDb\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x42R\n8es.bsc.dataclay.communication.grpc.generated.logicmoduleB\x16LogicModuleGrpcServiceb\x06proto3')



_LOGICMODULE = DESCRIPTOR.services_by_name['LogicModule']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8es.bsc.dataclay.communication.grpc.generated.logicmoduleB\026LogicModuleGrpcService'
  _LOGICMODULE._serialized_start=114
  _LOGICMODULE._serialized_end=11815
# @@protoc_insertion_point(module_scope)
