# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2
from . import dataservice_messages_pb2 as protos_dot_dataservice__messages__pb2
from . import dataservice_pb2 as protos_dot_dataservice__pb2


class DataServiceStub(object):
    """Interface exported by the server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.initBackendID = channel.unary_unary(
                '/protos.dataservice.DataService/initBackendID',
                request_serializer=protos_dot_dataservice__messages__pb2.InitBackendIDRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.associateExecutionEnvironment = channel.unary_unary(
                '/protos.dataservice.DataService/associateExecutionEnvironment',
                request_serializer=protos_dot_dataservice__messages__pb2.AssociateExecutionEnvironmentRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deployMetaClasses = channel.unary_unary(
                '/protos.dataservice.DataService/deployMetaClasses',
                request_serializer=protos_dot_dataservice__messages__pb2.DeployMetaClassesRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deployClasses = channel.unary_unary(
                '/protos.dataservice.DataService/deployClasses',
                request_serializer=protos_dot_dataservice__messages__pb2.DeployClassesRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.enrichClass = channel.unary_unary(
                '/protos.dataservice.DataService/enrichClass',
                request_serializer=protos_dot_dataservice__messages__pb2.EnrichClassRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.newPersistentInstance = channel.unary_unary(
                '/protos.dataservice.DataService/newPersistentInstance',
                request_serializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceResponse.FromString,
                )
        self.storeObjects = channel.unary_unary(
                '/protos.dataservice.DataService/storeObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.StoreObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getCopyOfObject = channel.unary_unary(
                '/protos.dataservice.DataService/getCopyOfObject',
                request_serializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectResponse.FromString,
                )
        self.updateObject = channel.unary_unary(
                '/protos.dataservice.DataService/updateObject',
                request_serializer=protos_dot_dataservice__messages__pb2.UpdateObjectRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getObjects = channel.unary_unary(
                '/protos.dataservice.DataService/getObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.GetObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetObjectsResponse.FromString,
                )
        self.newVersion = channel.unary_unary(
                '/protos.dataservice.DataService/newVersion',
                request_serializer=protos_dot_dataservice__messages__pb2.NewVersionRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.NewVersionResponse.FromString,
                )
        self.consolidateVersion = channel.unary_unary(
                '/protos.dataservice.DataService/consolidateVersion',
                request_serializer=protos_dot_dataservice__messages__pb2.ConsolidateVersionRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.upsertObjects = channel.unary_unary(
                '/protos.dataservice.DataService/upsertObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.UpsertObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.newReplica = channel.unary_unary(
                '/protos.dataservice.DataService/newReplica',
                request_serializer=protos_dot_dataservice__messages__pb2.NewReplicaRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.NewReplicaResponse.FromString,
                )
        self.moveObjects = channel.unary_unary(
                '/protos.dataservice.DataService/moveObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.MoveObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.MoveObjectsResponse.FromString,
                )
        self.removeObjects = channel.unary_unary(
                '/protos.dataservice.DataService/removeObjects',
                request_serializer=protos_dot_dataservice__messages__pb2.RemoveObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.RemoveObjectsResponse.FromString,
                )
        self.migrateObjectsToBackends = channel.unary_unary(
                '/protos.dataservice.DataService/migrateObjectsToBackends',
                request_serializer=protos_dot_dataservice__messages__pb2.MigrateObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.MigrateObjectsResponse.FromString,
                )
        self.getClassIDFromObjectInMemory = channel.unary_unary(
                '/protos.dataservice.DataService/getClassIDFromObjectInMemory',
                request_serializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryResponse.FromString,
                )
        self.executeImplementation = channel.unary_unary(
                '/protos.dataservice.DataService/executeImplementation',
                request_serializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationResponse.FromString,
                )
        self.makePersistent = channel.unary_unary(
                '/protos.dataservice.DataService/makePersistent',
                request_serializer=protos_dot_dataservice__messages__pb2.OldMakePersistentRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.federate = channel.unary_unary(
                '/protos.dataservice.DataService/federate',
                request_serializer=protos_dot_dataservice__messages__pb2.FederateRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.unfederate = channel.unary_unary(
                '/protos.dataservice.DataService/unfederate',
                request_serializer=protos_dot_dataservice__messages__pb2.UnfederateRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.notifyFederation = channel.unary_unary(
                '/protos.dataservice.DataService/notifyFederation',
                request_serializer=protos_dot_dataservice__messages__pb2.NotifyFederationRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.notifyUnfederation = channel.unary_unary(
                '/protos.dataservice.DataService/notifyUnfederation',
                request_serializer=protos_dot_dataservice__messages__pb2.NotifyUnfederationRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.exists = channel.unary_unary(
                '/protos.dataservice.DataService/exists',
                request_serializer=protos_dot_dataservice__messages__pb2.ExistsRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.ExistsResponse.FromString,
                )
        self.synchronize = channel.unary_unary(
                '/protos.dataservice.DataService/synchronize',
                request_serializer=protos_dot_dataservice__messages__pb2.SynchronizeRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.storeToDB = channel.unary_unary(
                '/protos.dataservice.DataService/storeToDB',
                request_serializer=protos_dot_dataservice__messages__pb2.StoreToDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getFromDB = channel.unary_unary(
                '/protos.dataservice.DataService/getFromDB',
                request_serializer=protos_dot_dataservice__messages__pb2.GetFromDBRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetFromDBResponse.FromString,
                )
        self.updateToDB = channel.unary_unary(
                '/protos.dataservice.DataService/updateToDB',
                request_serializer=protos_dot_dataservice__messages__pb2.UpdateToDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deleteToDB = channel.unary_unary(
                '/protos.dataservice.DataService/deleteToDB',
                request_serializer=protos_dot_dataservice__messages__pb2.DeleteToDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deleteSetFromDB = channel.unary_unary(
                '/protos.dataservice.DataService/deleteSetFromDB',
                request_serializer=protos_dot_dataservice__messages__pb2.DeleteSetFromDBRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.existsInDB = channel.unary_unary(
                '/protos.dataservice.DataService/existsInDB',
                request_serializer=protos_dot_dataservice__messages__pb2.ExistsInDBRequest.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.ExistsInDBResponse.FromString,
                )
        self.cleanExecutionClassDirectory = channel.unary_unary(
                '/protos.dataservice.DataService/cleanExecutionClassDirectory',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.closeDbHandler = channel.unary_unary(
                '/protos.dataservice.DataService/closeDbHandler',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.shutDown = channel.unary_unary(
                '/protos.dataservice.DataService/shutDown',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.disconnectFromOthers = channel.unary_unary(
                '/protos.dataservice.DataService/disconnectFromOthers',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.registerPendingObjects = channel.unary_unary(
                '/protos.dataservice.DataService/registerPendingObjects',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.cleanCaches = channel.unary_unary(
                '/protos.dataservice.DataService/cleanCaches',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.activateTracing = channel.unary_unary(
                '/protos.dataservice.DataService/activateTracing',
                request_serializer=protos_dot_dataservice__messages__pb2.ActivateTracingRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deactivateTracing = channel.unary_unary(
                '/protos.dataservice.DataService/deactivateTracing',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getTraces = channel.unary_unary(
                '/protos.dataservice.DataService/getTraces',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetTracesResponse.FromString,
                )
        self.deleteAlias = channel.unary_unary(
                '/protos.dataservice.DataService/deleteAlias',
                request_serializer=protos_dot_dataservice__messages__pb2.DeleteAliasRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.detachObjectFromSession = channel.unary_unary(
                '/protos.dataservice.DataService/detachObjectFromSession',
                request_serializer=protos_dot_dataservice__messages__pb2.DetachObjectFromSessionRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.closeSessionInDS = channel.unary_unary(
                '/protos.dataservice.DataService/closeSessionInDS',
                request_serializer=protos_dot_dataservice__messages__pb2.CloseSessionInDSRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getRetainedReferences = channel.unary_unary(
                '/protos.dataservice.DataService/getRetainedReferences',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetRetainedReferencesResponse.FromString,
                )
        self.getNumObjects = channel.unary_unary(
                '/protos.dataservice.DataService/getNumObjects',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
                )
        self.getNumObjectsInEE = channel.unary_unary(
                '/protos.dataservice.DataService/getNumObjectsInEE',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
                )
        self.getObjectGraph = channel.unary_unary(
                '/protos.dataservice.DataService/getObjectGraph',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_dataservice__messages__pb2.GetObjectGraphResponse.FromString,
                )
        self.MakePersistent = channel.unary_unary(
                '/protos.dataservice.DataService/MakePersistent',
                request_serializer=protos_dot_dataservice__pb2.MakePersistentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CallActiveMethod = channel.unary_unary(
                '/protos.dataservice.DataService/CallActiveMethod',
                request_serializer=protos_dot_dataservice__pb2.CallActiveMethodRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
                )


class DataServiceServicer(object):
    """Interface exported by the server.
    """

    def initBackendID(self, request, context):
        """Deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def associateExecutionEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deployMetaClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deployClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enrichClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newPersistentInstance(self, request, context):
        """Execution Environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def storeObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getCopyOfObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def consolidateVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def upsertObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newReplica(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def moveObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def migrateObjectsToBackends(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassIDFromObjectInMemory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def executeImplementation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def makePersistent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def federate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def unfederate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notifyFederation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notifyUnfederation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def exists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def synchronize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def storeToDB(self, request, context):
        """Storage Location
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getFromDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateToDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteToDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteSetFromDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def existsInDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cleanExecutionClassDirectory(self, request, context):
        """Others
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeDbHandler(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def shutDown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disconnectFromOthers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerPendingObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cleanCaches(self, request, context):
        """Paraver
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def activateTracing(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deactivateTracing(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getTraces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteAlias(self, request, context):
        """Garbage collection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def detachObjectFromSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeSessionInDS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getRetainedReferences(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNumObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNumObjectsInEE(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjectGraph(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MakePersistent(self, request, context):
        """NEW
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallActiveMethod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'initBackendID': grpc.unary_unary_rpc_method_handler(
                    servicer.initBackendID,
                    request_deserializer=protos_dot_dataservice__messages__pb2.InitBackendIDRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'associateExecutionEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.associateExecutionEnvironment,
                    request_deserializer=protos_dot_dataservice__messages__pb2.AssociateExecutionEnvironmentRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deployMetaClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.deployMetaClasses,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeployMetaClassesRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deployClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.deployClasses,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeployClassesRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'enrichClass': grpc.unary_unary_rpc_method_handler(
                    servicer.enrichClass,
                    request_deserializer=protos_dot_dataservice__messages__pb2.EnrichClassRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'newPersistentInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.newPersistentInstance,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.NewPersistentInstanceResponse.SerializeToString,
            ),
            'storeObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.storeObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.StoreObjectsRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getCopyOfObject': grpc.unary_unary_rpc_method_handler(
                    servicer.getCopyOfObject,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetCopyOfObjectResponse.SerializeToString,
            ),
            'updateObject': grpc.unary_unary_rpc_method_handler(
                    servicer.updateObject,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UpdateObjectRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetObjectsResponse.SerializeToString,
            ),
            'newVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.newVersion,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NewVersionRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.NewVersionResponse.SerializeToString,
            ),
            'consolidateVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.consolidateVersion,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ConsolidateVersionRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'upsertObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.upsertObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UpsertObjectsRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'newReplica': grpc.unary_unary_rpc_method_handler(
                    servicer.newReplica,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NewReplicaRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.NewReplicaResponse.SerializeToString,
            ),
            'moveObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.moveObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.MoveObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.MoveObjectsResponse.SerializeToString,
            ),
            'removeObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.removeObjects,
                    request_deserializer=protos_dot_dataservice__messages__pb2.RemoveObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.RemoveObjectsResponse.SerializeToString,
            ),
            'migrateObjectsToBackends': grpc.unary_unary_rpc_method_handler(
                    servicer.migrateObjectsToBackends,
                    request_deserializer=protos_dot_dataservice__messages__pb2.MigrateObjectsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.MigrateObjectsResponse.SerializeToString,
            ),
            'getClassIDFromObjectInMemory': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassIDFromObjectInMemory,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryResponse.SerializeToString,
            ),
            'executeImplementation': grpc.unary_unary_rpc_method_handler(
                    servicer.executeImplementation,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.ExecuteImplementationResponse.SerializeToString,
            ),
            'makePersistent': grpc.unary_unary_rpc_method_handler(
                    servicer.makePersistent,
                    request_deserializer=protos_dot_dataservice__messages__pb2.OldMakePersistentRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'federate': grpc.unary_unary_rpc_method_handler(
                    servicer.federate,
                    request_deserializer=protos_dot_dataservice__messages__pb2.FederateRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'unfederate': grpc.unary_unary_rpc_method_handler(
                    servicer.unfederate,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UnfederateRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'notifyFederation': grpc.unary_unary_rpc_method_handler(
                    servicer.notifyFederation,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NotifyFederationRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'notifyUnfederation': grpc.unary_unary_rpc_method_handler(
                    servicer.notifyUnfederation,
                    request_deserializer=protos_dot_dataservice__messages__pb2.NotifyUnfederationRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'exists': grpc.unary_unary_rpc_method_handler(
                    servicer.exists,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ExistsRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.ExistsResponse.SerializeToString,
            ),
            'synchronize': grpc.unary_unary_rpc_method_handler(
                    servicer.synchronize,
                    request_deserializer=protos_dot_dataservice__messages__pb2.SynchronizeRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'storeToDB': grpc.unary_unary_rpc_method_handler(
                    servicer.storeToDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.StoreToDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getFromDB': grpc.unary_unary_rpc_method_handler(
                    servicer.getFromDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.GetFromDBRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetFromDBResponse.SerializeToString,
            ),
            'updateToDB': grpc.unary_unary_rpc_method_handler(
                    servicer.updateToDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.UpdateToDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deleteToDB': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteToDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeleteToDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deleteSetFromDB': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteSetFromDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeleteSetFromDBRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'existsInDB': grpc.unary_unary_rpc_method_handler(
                    servicer.existsInDB,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ExistsInDBRequest.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.ExistsInDBResponse.SerializeToString,
            ),
            'cleanExecutionClassDirectory': grpc.unary_unary_rpc_method_handler(
                    servicer.cleanExecutionClassDirectory,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'closeDbHandler': grpc.unary_unary_rpc_method_handler(
                    servicer.closeDbHandler,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'shutDown': grpc.unary_unary_rpc_method_handler(
                    servicer.shutDown,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'disconnectFromOthers': grpc.unary_unary_rpc_method_handler(
                    servicer.disconnectFromOthers,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'registerPendingObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.registerPendingObjects,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'cleanCaches': grpc.unary_unary_rpc_method_handler(
                    servicer.cleanCaches,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'activateTracing': grpc.unary_unary_rpc_method_handler(
                    servicer.activateTracing,
                    request_deserializer=protos_dot_dataservice__messages__pb2.ActivateTracingRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deactivateTracing': grpc.unary_unary_rpc_method_handler(
                    servicer.deactivateTracing,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getTraces': grpc.unary_unary_rpc_method_handler(
                    servicer.getTraces,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetTracesResponse.SerializeToString,
            ),
            'deleteAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteAlias,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DeleteAliasRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'detachObjectFromSession': grpc.unary_unary_rpc_method_handler(
                    servicer.detachObjectFromSession,
                    request_deserializer=protos_dot_dataservice__messages__pb2.DetachObjectFromSessionRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'closeSessionInDS': grpc.unary_unary_rpc_method_handler(
                    servicer.closeSessionInDS,
                    request_deserializer=protos_dot_dataservice__messages__pb2.CloseSessionInDSRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getRetainedReferences': grpc.unary_unary_rpc_method_handler(
                    servicer.getRetainedReferences,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetRetainedReferencesResponse.SerializeToString,
            ),
            'getNumObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.getNumObjects,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.SerializeToString,
            ),
            'getNumObjectsInEE': grpc.unary_unary_rpc_method_handler(
                    servicer.getNumObjectsInEE,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.SerializeToString,
            ),
            'getObjectGraph': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjectGraph,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_dataservice__messages__pb2.GetObjectGraphResponse.SerializeToString,
            ),
            'MakePersistent': grpc.unary_unary_rpc_method_handler(
                    servicer.MakePersistent,
                    request_deserializer=protos_dot_dataservice__pb2.MakePersistentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CallActiveMethod': grpc.unary_unary_rpc_method_handler(
                    servicer.CallActiveMethod,
                    request_deserializer=protos_dot_dataservice__pb2.CallActiveMethodRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_wrappers__pb2.BytesValue.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.dataservice.DataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataService(object):
    """Interface exported by the server.
    """

    @staticmethod
    def initBackendID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/initBackendID',
            protos_dot_dataservice__messages__pb2.InitBackendIDRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def associateExecutionEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/associateExecutionEnvironment',
            protos_dot_dataservice__messages__pb2.AssociateExecutionEnvironmentRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deployMetaClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deployMetaClasses',
            protos_dot_dataservice__messages__pb2.DeployMetaClassesRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deployClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deployClasses',
            protos_dot_dataservice__messages__pb2.DeployClassesRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enrichClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/enrichClass',
            protos_dot_dataservice__messages__pb2.EnrichClassRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newPersistentInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/newPersistentInstance',
            protos_dot_dataservice__messages__pb2.NewPersistentInstanceRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.NewPersistentInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def storeObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/storeObjects',
            protos_dot_dataservice__messages__pb2.StoreObjectsRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getCopyOfObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getCopyOfObject',
            protos_dot_dataservice__messages__pb2.GetCopyOfObjectRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetCopyOfObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/updateObject',
            protos_dot_dataservice__messages__pb2.UpdateObjectRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getObjects',
            protos_dot_dataservice__messages__pb2.GetObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/newVersion',
            protos_dot_dataservice__messages__pb2.NewVersionRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.NewVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def consolidateVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/consolidateVersion',
            protos_dot_dataservice__messages__pb2.ConsolidateVersionRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def upsertObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/upsertObjects',
            protos_dot_dataservice__messages__pb2.UpsertObjectsRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newReplica(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/newReplica',
            protos_dot_dataservice__messages__pb2.NewReplicaRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.NewReplicaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def moveObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/moveObjects',
            protos_dot_dataservice__messages__pb2.MoveObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.MoveObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/removeObjects',
            protos_dot_dataservice__messages__pb2.RemoveObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.RemoveObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def migrateObjectsToBackends(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/migrateObjectsToBackends',
            protos_dot_dataservice__messages__pb2.MigrateObjectsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.MigrateObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassIDFromObjectInMemory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getClassIDFromObjectInMemory',
            protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetClassIDFromObjectInMemoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def executeImplementation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/executeImplementation',
            protos_dot_dataservice__messages__pb2.ExecuteImplementationRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.ExecuteImplementationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def makePersistent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/makePersistent',
            protos_dot_dataservice__messages__pb2.OldMakePersistentRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def federate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/federate',
            protos_dot_dataservice__messages__pb2.FederateRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def unfederate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/unfederate',
            protos_dot_dataservice__messages__pb2.UnfederateRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notifyFederation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/notifyFederation',
            protos_dot_dataservice__messages__pb2.NotifyFederationRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notifyUnfederation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/notifyUnfederation',
            protos_dot_dataservice__messages__pb2.NotifyUnfederationRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def exists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/exists',
            protos_dot_dataservice__messages__pb2.ExistsRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.ExistsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def synchronize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/synchronize',
            protos_dot_dataservice__messages__pb2.SynchronizeRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def storeToDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/storeToDB',
            protos_dot_dataservice__messages__pb2.StoreToDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getFromDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getFromDB',
            protos_dot_dataservice__messages__pb2.GetFromDBRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetFromDBResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def updateToDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/updateToDB',
            protos_dot_dataservice__messages__pb2.UpdateToDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteToDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deleteToDB',
            protos_dot_dataservice__messages__pb2.DeleteToDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteSetFromDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deleteSetFromDB',
            protos_dot_dataservice__messages__pb2.DeleteSetFromDBRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def existsInDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/existsInDB',
            protos_dot_dataservice__messages__pb2.ExistsInDBRequest.SerializeToString,
            protos_dot_dataservice__messages__pb2.ExistsInDBResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cleanExecutionClassDirectory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/cleanExecutionClassDirectory',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def closeDbHandler(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/closeDbHandler',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def shutDown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/shutDown',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disconnectFromOthers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/disconnectFromOthers',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerPendingObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/registerPendingObjects',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cleanCaches(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/cleanCaches',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def activateTracing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/activateTracing',
            protos_dot_dataservice__messages__pb2.ActivateTracingRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deactivateTracing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deactivateTracing',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getTraces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getTraces',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetTracesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/deleteAlias',
            protos_dot_dataservice__messages__pb2.DeleteAliasRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def detachObjectFromSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/detachObjectFromSession',
            protos_dot_dataservice__messages__pb2.DetachObjectFromSessionRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def closeSessionInDS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/closeSessionInDS',
            protos_dot_dataservice__messages__pb2.CloseSessionInDSRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getRetainedReferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getRetainedReferences',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetRetainedReferencesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNumObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getNumObjects',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNumObjectsInEE(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getNumObjectsInEE',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjectGraph(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/getObjectGraph',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_dataservice__messages__pb2.GetObjectGraphResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MakePersistent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/MakePersistent',
            protos_dot_dataservice__pb2.MakePersistentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CallActiveMethod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.dataservice.DataService/CallActiveMethod',
            protos_dot_dataservice__pb2.CallActiveMethodRequest.SerializeToString,
            google_dot_protobuf_dot_wrappers__pb2.BytesValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
