# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2
from . import metadata_service_pb2 as protos_dot_metadata__service__pb2


class MetadataServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.NewAccount = channel.unary_unary(
                '/protos.metadata_service.MetadataService/NewAccount',
                request_serializer=protos_dot_metadata__service__pb2.NewAccountRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetAccount',
                request_serializer=protos_dot_metadata__service__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=protos_dot_metadata__service__pb2.GetAccountResponse.FromString,
                )
        self.NewSession = channel.unary_unary(
                '/protos.metadata_service.MetadataService/NewSession',
                request_serializer=protos_dot_metadata__service__pb2.NewSessionRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.Session.FromString,
                )
        self.CloseSession = channel.unary_unary(
                '/protos.metadata_service.MetadataService/CloseSession',
                request_serializer=protos_dot_metadata__service__pb2.CloseSessionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.NewDataset = channel.unary_unary(
                '/protos.metadata_service.MetadataService/NewDataset',
                request_serializer=protos_dot_metadata__service__pb2.NewDatasetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetAllExecutionEnvironments = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetAllExecutionEnvironments',
                request_serializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsRequest.SerializeToString,
                response_deserializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsResponse.FromString,
                )
        self.GetDataclayID = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetDataclayID',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=protos_dot_metadata__service__pb2.GetDataclayIDResponse.FromString,
                )
        self.AutoregisterEE = channel.unary_unary(
                '/protos.metadata_service.MetadataService/AutoregisterEE',
                request_serializer=protos_dot_metadata__service__pb2.AutoRegisterEERequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RegisterObject = channel.unary_unary(
                '/protos.metadata_service.MetadataService/RegisterObject',
                request_serializer=protos_dot_metadata__service__pb2.RegisterObjectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetObjectMDById = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetObjectMDById',
                request_serializer=protos_dot_metadata__service__pb2.GetObjectMDByIdRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ObjectMetadata.FromString,
                )
        self.GetObjectMDByAlias = channel.unary_unary(
                '/protos.metadata_service.MetadataService/GetObjectMDByAlias',
                request_serializer=protos_dot_metadata__service__pb2.GetObjectMDByAliasRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ObjectMetadata.FromString,
                )
        self.DeleteAlias = channel.unary_unary(
                '/protos.metadata_service.MetadataService/DeleteAlias',
                request_serializer=protos_dot_metadata__service__pb2.DeleteAliasRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class MetadataServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def NewAccount(self, request, context):
        """Account Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NewSession(self, request, context):
        """Session Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NewDataset(self, request, context):
        """Dataset Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllExecutionEnvironments(self, request, context):
        """EE-SL information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataclayID(self, request, context):
        """Federation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AutoregisterEE(self, request, context):
        """Autoregister
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterObject(self, request, context):
        """Object Metadata
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectMDById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetObjectMDByAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetadataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'NewAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.NewAccount,
                    request_deserializer=protos_dot_metadata__service__pb2.NewAccountRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=protos_dot_metadata__service__pb2.GetAccountRequest.FromString,
                    response_serializer=protos_dot_metadata__service__pb2.GetAccountResponse.SerializeToString,
            ),
            'NewSession': grpc.unary_unary_rpc_method_handler(
                    servicer.NewSession,
                    request_deserializer=protos_dot_metadata__service__pb2.NewSessionRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.Session.SerializeToString,
            ),
            'CloseSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseSession,
                    request_deserializer=protos_dot_metadata__service__pb2.CloseSessionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'NewDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.NewDataset,
                    request_deserializer=protos_dot_metadata__service__pb2.NewDatasetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetAllExecutionEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllExecutionEnvironments,
                    request_deserializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsRequest.FromString,
                    response_serializer=protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsResponse.SerializeToString,
            ),
            'GetDataclayID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataclayID,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=protos_dot_metadata__service__pb2.GetDataclayIDResponse.SerializeToString,
            ),
            'AutoregisterEE': grpc.unary_unary_rpc_method_handler(
                    servicer.AutoregisterEE,
                    request_deserializer=protos_dot_metadata__service__pb2.AutoRegisterEERequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RegisterObject': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterObject,
                    request_deserializer=protos_dot_metadata__service__pb2.RegisterObjectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetObjectMDById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectMDById,
                    request_deserializer=protos_dot_metadata__service__pb2.GetObjectMDByIdRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ObjectMetadata.SerializeToString,
            ),
            'GetObjectMDByAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.GetObjectMDByAlias,
                    request_deserializer=protos_dot_metadata__service__pb2.GetObjectMDByAliasRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ObjectMetadata.SerializeToString,
            ),
            'DeleteAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAlias,
                    request_deserializer=protos_dot_metadata__service__pb2.DeleteAliasRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.metadata_service.MetadataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MetadataService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def NewAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/NewAccount',
            protos_dot_metadata__service__pb2.NewAccountRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetAccount',
            protos_dot_metadata__service__pb2.GetAccountRequest.SerializeToString,
            protos_dot_metadata__service__pb2.GetAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NewSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/NewSession',
            protos_dot_metadata__service__pb2.NewSessionRequest.SerializeToString,
            protos_dot_common__messages__pb2.Session.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CloseSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/CloseSession',
            protos_dot_metadata__service__pb2.CloseSessionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NewDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/NewDataset',
            protos_dot_metadata__service__pb2.NewDatasetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllExecutionEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetAllExecutionEnvironments',
            protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsRequest.SerializeToString,
            protos_dot_metadata__service__pb2.GetAllExecutionEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataclayID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetDataclayID',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            protos_dot_metadata__service__pb2.GetDataclayIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AutoregisterEE(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/AutoregisterEE',
            protos_dot_metadata__service__pb2.AutoRegisterEERequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/RegisterObject',
            protos_dot_metadata__service__pb2.RegisterObjectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectMDById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetObjectMDById',
            protos_dot_metadata__service__pb2.GetObjectMDByIdRequest.SerializeToString,
            protos_dot_common__messages__pb2.ObjectMetadata.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetObjectMDByAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/GetObjectMDByAlias',
            protos_dot_metadata__service__pb2.GetObjectMDByAliasRequest.SerializeToString,
            protos_dot_common__messages__pb2.ObjectMetadata.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.metadata_service.MetadataService/DeleteAlias',
            protos_dot_metadata__service__pb2.DeleteAliasRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
